%
% Minimal test for the FREAnalysis function. Tests that the automated
% pairing based on distances created the right pairing.
%
% @author Ziv Yaniv (zivy@isis.georgetown.edu)
%
function FREAnalysisTest()
        %original points 
pointsInLeft = [[10; 0; 0], [0; 20; 0], [0; 0; 30]];
n = size(pointsInLeft,2);

         %create random rigid transformation
         %1. Random rotation.
         %2. Random translation.
[R, S, V]  = svd(rand(3,3));
t = 100*rand(3,1);
T = [R,t;[0, 0, 0, 1]];

         %create transformed points with additive Gaussian noise
pointsInRight = T*[pointsInLeft;ones(1,n)];
gaussianNoise = randn(3,n);
pointsInRight = pointsInRight(1:3,:) + gaussianNoise;

         %run the function
[FRE, distances] = FREAnalysis(pointsInLeft, pointsInRight(:,randperm(n)));

         %compare results using known pairings
Testimated = absoluteOrientation(pointsInLeft, pointsInRight);
transformedHomogenousPoints = Testimated*[pointsInLeft;ones(1,n)];
squaredErrors =  (transformedHomogenousPoints(1:3,:) - pointsInRight).^2;
FREKnownPairings = sqrt(sum(squaredErrors(:))/n);
distancesKnownPairings = sqrt(sum(squaredErrors,1)); 
if (FRE - FREKnownPairings) < eps && ...
    all((distances - distancesKnownPairings) < eps)
    fprintf('test passed\n');
    fprintf('***********\n');
    fprintf('FRE for known pairings: %.2f\n', FREKnownPairings);
    fprintf('FRE for matched pairings: %.2f\n', FRE);
    fprintf('distances for known pairings: ');
    fprintf('%.2f ', distancesKnownPairings);
    fprintf('\n');
    fprintf('distances for matched pairings: ');
    fprintf('%.2f ', distances);
    fprintf('\n');
else
  fprintf('test failed\n');
end
