%
% Create a rigid transformation frame using X-Y-Z fixed angles 
% notation (R = R_z*R_y*R_x).
%
% @param thetaX Rotation around the x axis. The value can be either in 
%               degrees or radians (see angleInDegrees paramater).
%
% @param thetaY Rotation around the y axis. The value can be either in 
%               degrees or radians (see angleInDegrees paramater).
%
% @param thetaZ Rotation around the z axis. The value can be either in 
%               degrees or radians (see angleInDegrees paramater).
%
% @param dx Translation in the x axis direction.
%
% @param dy Translation in the y axis direction.
%
% @param dz Translation in the z axis direction.
%
% @param angleInDegrees Boolean denoting if the angles were given in
%                       degrees (angleInDegrees==1) or radians 
%                       (angleInDegrees==0).
%
% @return res A 4x4 rigid transformation frame [R|t]
%                                              [0|1]
%
% @author Ziv Yaniv (zivy@isis.georgetown.edu)
%
function res = createFixedAxisFrame(thetaX,thetaY,thetaZ,dx,dy,dz,angleInDegrees)

  if(angleInDegrees == 1)
    s1 = sind(thetaZ); s2 = sind(thetaY); s3 = sind(thetaX);
    c1 = cosd(thetaZ); c2 = cosd(thetaY); c3 = cosd(thetaX);
  else
    s1 = sin(thetaZ); s2 = sin(thetaY); s3 = sin(thetaX);
    c1 = cos(thetaZ); c2 = cos(thetaY); c3 = cos(thetaX);
  end    
  res(1,1) = c1*c2; res(1,2) = c1*s2*s3 - s1*c3;  res(1,3) = c1*s2*c3+s1*s3;     res(1,4) = dx;
  res(2,1) = s1*c2; res(2,2) = s1*s2*s3 + c1*c3 ; res(2,3) = s1*s2*c3 - c1*s3;   res(2,4) = dy;
  res(3,1) = -s2;   res(3,2) = c2*s3;             res(3,3) = c2*c3;              res(3,4) = dz;   
  res(4,1) = 0;     res(4,2) = 0;                 res(4,3) = 0;                  res(4,4) = 1;


function result = cosd(angle)
  result = cos(angle * pi/180);

function result = sind(angle)
  result = sin(angle * pi/180);
  